# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# Do a systemd-based build from F-15; otherwise, a sysvinit-based build
%global use_systemd %([ "(" "%{__distinit}" == "fc" -a %{__distvers} -gt 14 ")" -o "(" "%{__distinit}" == "rhel" -a %{__distvers} -gt 6 ")" ] && echo 1 || echo 0)

# systemd-units merged into systemd at Fedora 17
%if (0%{?fedora} && 0%{?fedora} <= 16)
%global systemd_units systemd-units
%else
%global systemd_units systemd
%endif

# Do a hardened build where possible
%define _hardened_build 1

Summary:	Uptime Daemon
Name:		ud
Version:	0.7.1
Release:	7.%{__distinit}%{__distvers}
License:	GPL+
URL:		http://packages.debian.org/testing/misc/ud
Source0:	http://ftp.debian.org/debian/pool/main/u/ud/ud_0.7.1.orig.tar.gz
Source1:	ud.service
Patch0:		http://ftp.debian.org/debian/pool/main/u/ud/ud_0.7.1-21.diff.gz
Patch1:		ud-0.7.1-autotools.patch.gz
Patch2:		ud-0.7.1-initscript.patch
Patch3:		ud-0.7.1-utf8.patch
BuildRequires:	coreutils
BuildRequires:	gcc
BuildRequires:	make
%if %{use_systemd}
BuildRequires:	%{systemd_units}
Requires(post):	%{systemd_units}
Requires(preun): %{systemd_units}
Requires(postun): %{systemd_units}
%else
Requires(post): chkconfig
Requires(post): initscripts
Requires(preun): chkconfig
Requires(preun): initscripts
Requires(postun): initscripts
%endif

%description
UD runs in the background constantly checking the current uptime against
your 3 best uptime records. If the current uptime surpasses a record, that
becomes the new record.

By using a template, UD can create HTML files that show the current uptime
records. The HTML files are updated by the daemon.

%prep
%setup -q -n ud-%{version}.orig
cp -p %{SOURCE1} ./
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
echo 'UDOPTIONS="-s"' > ud.sysconfig
touch config.sub config.guess
chmod -c +x config.sub config.guess

# Use the linux-gnu uptime routine
cd sysdeps/
ln -s linux-gnu/* ./
cd -

%build
%configure
# Parallel build unreliable
make

%install
make DESTDIR=%{buildroot} install
install -d -m 755 %{buildroot}%{_sysconfdir}/ud
install -d -m 755 %{buildroot}%{_sysconfdir}/sysconfig
install -d -m 755 %{buildroot}%{_mandir}/man1
mv -f %{buildroot}%{_sysconfdir}/template.ud %{buildroot}%{_sysconfdir}/ud/template.html
install -p -m 644 ud.sysconfig %{buildroot}%{_sysconfdir}/sysconfig/ud
install -p -m 644 debian/ud.1 %{buildroot}%{_mandir}/man1
%if %{use_systemd}
install -d -m 755 %{buildroot}%{_unitdir}
install -p -m 644 ud.service %{buildroot}%{_unitdir}
%else
install -d -m 755 %{buildroot}%{_initrddir}
install -p -m 755 ud.initscript %{buildroot}%{_initrddir}/ud
%endif

%post
%if %{use_systemd}
systemctl daemon-reload &>/dev/null || :
%else
if [ $1 -eq 1 ]; then
	# Initial installation
	chkconfig --add ud || :
fi
%endif

%preun
if [ $1 -eq 0 ]; then
	# Package removal, not upgrade
%if %{use_systemd}
	systemctl stop ud.service &>/dev/null || :
	systemctl --no-reload disable ud.service &>/dev/null || :
%else
	service ud stop &>/dev/null || :
	chkconfig --del ud || :
%endif
fi

%postun
%if %{use_systemd}
systemctl daemon-reload &>/dev/null || :
%endif
if [ $1 -ge 1 ]; then
	# Package upgrade, not uninstall
%if %{use_systemd}
	systemctl try-restart ud.service &>/dev/null || :
%else
	[ -f /var/lock/subsys/ud ] && service ud restart &>/dev/null || :
%endif
fi

%files
%if 0%{?_licensedir:1}
%license COPYING
%else
%doc COPYING
%endif
%doc README NEWS TEMPLATE-CODES AUTHORS ChangeLog template
%{_bindir}/ud
%if %{use_systemd}
%{_unitdir}/ud.service
%else
%{_initrddir}/ud
%endif
%dir %{_sysconfdir}/ud
%config(noreplace) %{_sysconfdir}/sysconfig/ud
%config(noreplace) %{_sysconfdir}/ud/template.html
%{_mandir}/man1/ud.1*

%changelog
* Fri Mar  9 2018 Paul Howarth <paul@city-fan.org> - 0.7.1-7
- systemd-units merged into systemd at Fedora 17
- Improve scriptlet readability by avoiding use of full paths for commands

* Thu Aug 10 2017 Paul Howarth <paul@city-fan.org> - 0.7.1-6
- Specify build requirements
- Use %%license where possible
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop %%defattr

* Sun Jul 28 2013 Paul Howarth <paul@city-fan.org> - 0.7.1-5
- systemd detection was broken in F-19 so hardcode it instead

* Fri Apr 20 2012 Paul Howarth <paul@city-fan.org> - 0.7.1-4
- Do a hardened build where possible
- Nobody else likes macros for commands
- Use native systemd init for systemd-based distros
- Add dist tag

* Fri Feb 11 2011 Paul Howarth <paul@city-fan.org> - 0.7.1-3
- Update to release 21 of the Debian patch
- Clean buildroot unconditionally
- Recode spec file as UTF-8
- Fix up initial config.{guess,sub} so configure script doesn't fail
- Don't attempt parallel build
- Use the linux-gnu uptime routine
- Include manpage for ud

* Wed Jul 20 2005 Paul Howarth <paul@city-fan.org> - 0.7.1-2
- Spec file rewritten
- Portability patch imported from debian

* Sat Apr 24 1999 Arnaud Gomes-do-Vale <arnaud@carrosse.frmug.org>
- Upgraded from 0.2.3 to 0.7.1

* Sun Jun 14 1998 Arkadiusz Miśkiewicz <misiek@misiek.eu.org>
- Initial package release
